@@ -84,6 +84,7 @@
     ("rc" . sh-mode)
     ("sh" . sh-mode)
     ("sh5" . sh-mode)
+    ("cmd" . sh-mode)
     ("tcsh" . sh-mode)
     ("wksh" . sh-mode)
     ("wsh" . sh-mode)
@@ -117,6 +118,7 @@ If it matches, mode MODE is selected.")
     (itcsh . tcsh)
     (jcsh . csh)
     (jsh . sh)
+    (cmd . sh)
     (ksh . ksh88)
     (ksh88 . jsh)
     (oash . sh)
@@ -857,7 +859,10 @@ Calls the value of `sh-set-shell-hook' if set."
 				      (lambda (x) (eq (cdr x) 'sh-mode)))
 		     (eq executable-query 'function)
 		     t))
-  (setq sh-shell (intern (file-name-nondirectory shell))
+  ;; XEmacs change: we need to strip the extension in case we
+  ;; are running under mswindows
+  (setq sh-shell (intern (file-name-sans-extension
+			  (file-name-nondirectory shell)))
 	sh-shell (or (cdr (assq sh-shell sh-alias-alist))
 		     sh-shell))
   (setq sh-shell-file (executable-set-magic shell (sh-feature sh-shell-arg)))
